@@ -11,12 +11,13 @@
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; version 2 of the License.               *
+ *   the Free Software Foundation; version 2 of the License or             *
+ *   (at your option) version 3.                                           *
  *                                                                         *
  ***************************************************************************/
 
-#ifndef _KDEEXPORTFIX_H_
-#define _KDEEXPORTFIX_H_
+#ifndef KDEEXPORTFIX_H
+#define KDEEXPORTFIX_H
 
 #include <kdeversion.h>
 #if KDE_VERSION < KDE_MAKE_VERSION (3,3,2)
@@ -24,4 +25,4 @@
 #define KDE_EXPORT
 #endif
 
-#endif      // _KDEEXPORTFIX_H_
+#endif      // KDEEXPORTFIX_H
