@@ -2,28 +2,36 @@
     begin                : Sun Feb 17 2002
     copyright            : (C) 2002 - 2004 by Scott Wheeler
     email                : wheeler@kde.org
-***************************************************************************/
 
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
+
+  This program is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
+
+  You should have received a copy of the GNU General Public License
+  along with this program; if not, write to the Free Software
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ ******************************************************************************/
 
 #ifndef PLAYER_H
 #define PLAYER_H
 
-#include <qobject.h>
-#include <qstringlist.h>
+// Qt includes.
+#include <QtCore/QObject>
+#include <QtCore/QStringList>
+#include <QtCore/QByteArray>
+
+// KDE includes.
 #include <kdemacros.h>
-#include "kdeexportfix.h"
 
 // #include "filehandle.h"
 
-class KDE_EXPORT Player : virtual public QObject
+class KDE_EXPORT Player : public QObject
 {
     Q_OBJECT
 
@@ -48,7 +56,7 @@ public:
     virtual void seek(int seekTime) = 0;
     virtual void seekPosition(int position) = 0;
 
-    virtual QStringList getPluginList( const QCString& classname ) {
+    virtual QStringList getPluginList( const QByteArray& classname ) {
         Q_UNUSED(classname);
         return QStringList();
     }
@@ -65,8 +73,8 @@ public:
 
 protected:
     Player(QObject* parent = 0, const char* name = 0, const QStringList& args=QStringList() ) :
-        QObject(parent, name) { (void)args; }
+        QObject(parent) { Q_UNUSED(name); Q_UNUSED(args); }
 
 };
 
-#endif
+#endif // PLAYER_H
