@@ -23,8 +23,10 @@
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  ******************************************************************************/
 
-#ifndef _STRETCHER_H_
-#define _STRETCHER_H_
+#ifndef STRETCHER_H
+#define STRETCHER_H
+
+#include <QObject>
 
 #include <kdemacros.h>
 
@@ -61,12 +63,12 @@ class KDE_EXPORT Stretcher : public QObject{
         /**
         * Returns the state of the Stretcher.
         */
-        int getState();
+        int getState() const;
 
         /**
          * Returns the output filename (as given in call to stretch).
          */
-        QString getOutFilename();
+        QString getOutFilename() const;
 
         /**
         * Acknowledges the finished stretching.
@@ -93,4 +95,4 @@ class KDE_EXPORT Stretcher : public QObject{
         QString m_outFilename;
 };
 
-#endif      // _STRETCHER_H_
+#endif      // STRETCHER_H
